summaryrefslogtreecommitdiff
path: root/daemon/version/__init__.py
diff options
context:
space:
mode:
authorLorry Tar Creator <lorry-tar-importer@baserock.org>2014-08-04 05:45:35 +0000
committer <>2014-12-10 05:33:45 +0000
commitafcc4ea312255a2545f9c67d7c34ffefb00c80c0 (patch)
tree5ca5269e5d4fa6263242a7a96b713616e5f389e0 /daemon/version/__init__.py
parent02378192d5bb4b16498d87ace57da425166426bf (diff)
downloadpython-daemon-afcc4ea312255a2545f9c67d7c34ffefb00c80c0.tar.gz
Imported from /home/lorry/working-area/delta_python-packages_python-daemon/python-daemon-1.6.1.tar.gz.HEADpython-daemon-1.6.1master
Diffstat (limited to 'daemon/version/__init__.py')
-rw-r--r--daemon/version/__init__.py46
1 files changed, 28 insertions, 18 deletions
diff --git a/daemon/version/__init__.py b/daemon/version/__init__.py
index d2eafa6..2efb9d1 100644
--- a/daemon/version/__init__.py
+++ b/daemon/version/__init__.py
@@ -1,36 +1,46 @@
# -*- coding: utf-8 -*-
# daemon/version/__init__.py
-# Part of python-daemon, an implementation of PEP 3143.
+# Part of ‘python-daemon’, an implementation of PEP 3143.
+#
+# Copyright © 2008–2014 Ben Finney <ben+python@benfinney.id.au>
#
-# Copyright © 2008–2010 Ben Finney <ben+python@benfinney.id.au>
# This is free software: you may copy, modify, and/or distribute this work
-# under the terms of the Python Software Foundation License, version 2 or
-# later as published by the Python Software Foundation.
-# No warranty expressed or implied. See the file LICENSE.PSF-2 for details.
+# under the terms of the Apache License, version 2.0 as published by the
+# Apache Software Foundation.
+# No warranty expressed or implied. See the file LICENSE.ASF-2 for details.
+
+""" Version information for the ‘python-daemon’ distribution. """
-""" Version information for the python-daemon distribution. """
+from __future__ import (absolute_import, unicode_literals)
-from version_info import version_info
+from .version_info import version_info
-version_info['version_string'] = u"1.5.5"
+version_info['version_string'] = "1.6.1"
-version_short = u"%(version_string)s" % version_info
-version_full = u"%(version_string)s.r%(revno)s" % version_info
+version_short = "%(version_string)s" % version_info
+version_full = "%(version_string)s.r%(revno)s" % version_info
version = version_short
-author_name = u"Ben Finney"
-author_email = u"ben+python@benfinney.id.au"
-author = u"%(author_name)s <%(author_email)s>" % vars()
+author_name = "Ben Finney"
+author_email = "ben+python@benfinney.id.au"
+author = "%(author_name)s <%(author_email)s>" % vars()
-copyright_year_begin = u"2001"
+copyright_year_begin = "2001"
date = version_info['date'].split(' ', 1)[0]
copyright_year = date.split('-')[0]
copyright_year_range = copyright_year_begin
if copyright_year > copyright_year_begin:
- copyright_year_range += u"–%(copyright_year)s" % vars()
+ copyright_year_range += "–%(copyright_year)s" % vars()
copyright = (
- u"Copyright © %(copyright_year_range)s %(author)s and others"
- ) % vars()
-license = u"PSF-2+"
+ "Copyright © %(copyright_year_range)s %(author)s and others"
+ ) % vars()
+license = "Apache-2"
+
+
+# Local variables:
+# coding: utf-8
+# mode: python
+# End:
+# vim: fileencoding=utf-8 filetype=python :